import { Component, OnInit } from '@angular/core'
import { animate, state, style, transition, trigger } from '@angular/animations'
import {
    ApplicationTokens,
    ApiService
} from 'src/app/services/api.service'
import { Clipboard } from '@angular/cdk/clipboard'
import { ToastrService } from 'ngx-toastr'

@Component({
    selector: 'app-application-tokens',
    templateUrl: './application-tokens.component.html',
    styleUrls: ['./application-tokens.component.scss'],
    animations: [
        trigger('detailExpand', [
            state('collapsed', style({ height: '0px', minHeight: '0' })),
            state('expanded', style({ height: '*' })),
            transition('expanded <=> collapsed', animate('225ms cubic-bezier(0.4, 0.0, 0.2, 1)'))
        ])
    ]
})
export class ApplicationTokensComponent implements OnInit {
    dataSource: ApplicationTokens[] = []
    columnsToDisplay = ['name']
    columnsToDisplayWithExpand = [...this.columnsToDisplay, 'expand']
    expandedElement: string | null = ''

    constructor(
        private _apiService: ApiService,
        private _clipboard: Clipboard,
        private _toasterService: ToastrService
    ) {}

    ngOnInit(): void {
        this.getApplicationTokens()
    }

    getApplicationTokens() {
        this._apiService.getApplicationTokens().subscribe((response) => {
            this.dataSource = response
        })
    }

    copyTokenToClipboard(token: string): void {
        this._clipboard.copy(token)
        this._toasterService.info($localize`:@@copiedToClipboard: Copied to Clipboard`)
    }
}
