import { Component, OnDestroy, OnInit } from '@angular/core'
import { AuthService, Userinfo } from '../services/auth.service'
import { MatDialog, MAT_DIALOG_DATA } from '@angular/material/dialog'
import { DeleteDialog } from '../dialogs/delete-dialog/delete-dialog'
import { ToastrService } from 'ngx-toastr'
import { Subscription } from 'rxjs'

@Component({
    selector: 'app-user-profil',
    templateUrl: './user-profil.component.html',
    styleUrls: ['./user-profil.component.scss']
})
export class UserProfilComponent implements OnInit, OnDestroy {
    loggedIn: Userinfo | null = null
    dialogSub?: Subscription

    constructor(
        private _authService: AuthService,
        private _dialog: MatDialog,
        private _toasterService: ToastrService
    ) {}

    ngOnInit(): void {
        this._authService.loggedIn.subscribe((x) => (this.loggedIn = x))
    }

    ngOnDestroy(): void {
        this.dialogSub?.unsubscribe()
    }

    deleteAccount(): void {
        const dialogRef = this._dialog.open(DeleteDialog, {
            data: {
                headerText: $localize`:@@deleteAccountText:Delete Account`
            }
        })

        this.dialogSub = dialogRef.afterClosed().subscribe((confirmed) => {
            if (confirmed)
                this._authService.deleteUser().subscribe((response) => {
                    this._toasterService.success($localize`:@@toastMessageUserDeleted:User Deleted`)
                    this._authService.logout()
                })
        })
    }
}
